/// <reference types="node" />
import type { CommonPage } from '@crawlee/browser-pool';
export interface Page extends CommonPage {
    exposeFunction(name: string, callback: () => unknown): Promise<void>;
    on(eventName: string, handler: (msg: any) => Promise<void>): unknown;
    content(): unknown;
    screenshot(): unknown;
}
/**
 * Creates a string with an appended pageFunction to be evaluated in
 * the browser context and placed within the given namespace.
 */
export declare function wrapPageFunction(pageFunctionString: string, namespace: string): string;
/**
 * Attaches the provided function to the Browser context
 * by exposing it via page.exposeFunction. Returns a string
 * handle to be used to reference the exposed function in
 * the browser context.
 */
export declare function createBrowserHandle(page: Page, fun: (...args: unknown[]) => unknown): Promise<string>;
/**
 * Looks up a property descriptor for the given key in
 * the given object and its prototype chain.
 */
export declare function getPropertyDescriptor(target: object, key: PropertyKey): PropertyDescriptor | null;
/**
 * Exposes selected properties of an instance (of a Class or just an Object)
 * in the Browser context and returns their mapping.
 *
 * @param getters as TS will build all module methods as getters, we need to whitelist what are actual getters here
 */
export declare function createBrowserHandlesForObject<Instance extends object, Keys extends keyof Instance & string = keyof Instance & string>(page: Page, instance: Instance, properties: readonly Keys[], getters?: readonly PropertyKey[]): Promise<{ [K in Keys]: {
    value: Instance[K] extends (...args: any[]) => any ? string : Instance[K];
    type: 'METHOD' | 'VALUE' | 'GETTER';
}; }>;
export interface DumpConsoleOptions {
    /**
     * Prevents Browser context errors from being logged by default,
     * since there are usually a lot of errors produced by scraping
     * due to blocking resources, running headless, etc.
     */
    logErrors?: boolean;
}
/**
 * Attaches a console listener to page's console that
 * mirrors all console messages to the Node context.
 *
 * This is used instead of the "dumpio" launch option
 * to prevent cluttering the STDOUT with unnecessary
 * Chromium messages, usually internal errors, occurring in page.
 */
export declare function dumpConsole(page: Page, options?: DumpConsoleOptions): void;
export interface SnapshotOptions {
    page?: Page;
    body?: Buffer | string;
    contentType?: string | null;
    json?: any;
}
/**
 * Saves raw body and a screenshot to the default key value store
 * under the SNAPSHOT-BODY and SNAPSHOT-SCREENSHOT keys.
 */
export declare function saveSnapshot({ page, body, contentType, json }: SnapshotOptions): Promise<void>;
//# sourceMappingURL=browser_tools.d.ts.map