/**
 * Represents the key under which internal metadata
 * such as crawling depth are stored on the Request object.
 */
export declare const META_KEY = "__scraper-metadata__";
/**
 * The default resolution to be used by the browser instances.
 */
export declare const DEFAULT_VIEWPORT: {
    readonly width: 1920;
    readonly height: 1080;
};
/**
 * Error message produced by Browser on failed resource load. This is used to
 * suppress logging of this message when blocking resources.
 */
export declare const RESOURCE_LOAD_ERROR_MESSAGE = "Failed to load resource: net::ERR_FAILED";
/**
 * Name of file that holds Page Function in local development.
 */
export declare const PAGE_FUNCTION_FILENAME = "page_function.js";
/**
 * Just a requestHandler timeout value for when DevTools are used
 * so the user has time to browse the DevTools console.
 */
export declare const DEVTOOLS_TIMEOUT_SECS = 3600;
/**
 * Represents the keys under which saveSnapshot() will
 * persist to key value store and the throttling timeout.
 */
export declare const SNAPSHOT: {
    readonly KEYS: {
        readonly BODY: "SNAPSHOT-BODY";
        readonly SCREENSHOT: "SNAPSHOT-SCREENSHOT";
    };
    readonly TIMEOUT_SECS: 2;
};
/**
 * Enum values used in the Proxy Rotation (proxyRotation) input option.
 * Make sure those are always in sync!
 */
export declare const PROXY_ROTATION_NAMES: {
    readonly UNTIL_FAILURE: "UNTIL_FAILURE";
    readonly PER_REQUEST: "PER_REQUEST";
    readonly RECOMMENDED: "RECOMMENDED";
};
/**
 * Max usage counts of a Session per different available proxy rotations.
 */
export declare const SESSION_MAX_USAGE_COUNTS: {
    readonly UNTIL_FAILURE: 1000;
    readonly PER_REQUEST: 1;
    readonly RECOMMENDED: never;
};
//# sourceMappingURL=consts.d.ts.map