"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SESSION_MAX_USAGE_COUNTS = exports.PROXY_ROTATION_NAMES = exports.SNAPSHOT = exports.DEVTOOLS_TIMEOUT_SECS = exports.PAGE_FUNCTION_FILENAME = exports.RESOURCE_LOAD_ERROR_MESSAGE = exports.DEFAULT_VIEWPORT = exports.META_KEY = void 0;
/**
 * Represents the key under which internal metadata
 * such as crawling depth are stored on the Request object.
 */
exports.META_KEY = '__scraper-metadata__';
/**
 * The default resolution to be used by the browser instances.
 */
exports.DEFAULT_VIEWPORT = {
    width: 1920,
    height: 1080,
};
/**
 * Error message produced by Browser on failed resource load. This is used to
 * suppress logging of this message when blocking resources.
 */
exports.RESOURCE_LOAD_ERROR_MESSAGE = 'Failed to load resource: net::ERR_FAILED';
/**
 * Name of file that holds Page Function in local development.
 */
exports.PAGE_FUNCTION_FILENAME = 'page_function.js';
/**
 * Just a requestHandler timeout value for when DevTools are used
 * so the user has time to browse the DevTools console.
 */
exports.DEVTOOLS_TIMEOUT_SECS = 3600;
/**
 * Represents the keys under which saveSnapshot() will
 * persist to key value store and the throttling timeout.
 */
exports.SNAPSHOT = {
    KEYS: {
        BODY: 'SNAPSHOT-BODY',
        SCREENSHOT: 'SNAPSHOT-SCREENSHOT',
    },
    TIMEOUT_SECS: 2,
};
/**
 * Enum values used in the Proxy Rotation (proxyRotation) input option.
 * Make sure those are always in sync!
 */
exports.PROXY_ROTATION_NAMES = {
    UNTIL_FAILURE: 'UNTIL_FAILURE',
    PER_REQUEST: 'PER_REQUEST',
    RECOMMENDED: 'RECOMMENDED',
};
/**
 * Max usage counts of a Session per different available proxy rotations.
 */
exports.SESSION_MAX_USAGE_COUNTS = {
    [exports.PROXY_ROTATION_NAMES.UNTIL_FAILURE]: 1000,
    [exports.PROXY_ROTATION_NAMES.PER_REQUEST]: 1,
    [exports.PROXY_ROTATION_NAMES.RECOMMENDED]: undefined,
};
//# sourceMappingURL=consts.js.map