import type { KeyValueStore, RequestOptions, RequestQueueV2, RequestQueueOperationOptions } from '@crawlee/core';
import type { Dictionary } from '@crawlee/utils';
import type { ApifyEnv } from 'apify';
import { Actor } from 'apify';
export interface CrawlerSetupOptions {
    rawInput: string;
    env: ApifyEnv;
    globalStore: Map<string, unknown> | MapLike<string, unknown>;
    requestQueue: RequestQueueV2;
    keyValueStore: KeyValueStore;
    customData: unknown;
}
export interface MapLike<K, V> extends Omit<Map<K, V>, 'values' | 'keys' | 'entries' | 'set'> {
    keys: () => K[];
    values: () => V[];
    entries: () => [K, V][];
    set: (key: K, value: V) => MapLike<K, V>;
}
export interface ContextOptions {
    crawlerSetup: CrawlerSetupOptions;
    pageFunctionArguments: Dictionary;
}
interface InternalState {
    skipLinks: boolean;
}
declare const setup: unique symbol;
declare const internalState: unique symbol;
/**
 * Context represents everything that is available to the user
 * via Page Function. A class is used instead of a simple object
 * to avoid having to create new instances of functions with each
 * request.
 *
 * Some properties need to be accessible to the Context,
 * but should not be exposed to the user thus they are hidden
 * using a Symbol to prevent the user from easily accessing
 * and manipulating them.
 */
declare class Context<Options extends ContextOptions = ContextOptions, ExtraFields = Options['pageFunctionArguments']> {
    private readonly [setup];
    private readonly [internalState];
    readonly Actor: typeof Actor;
    readonly Apify: typeof Actor;
    readonly log: import("@apify/log").Log;
    readonly input: any;
    readonly env: ApifyEnv;
    readonly customData: unknown;
    readonly globalStore: Map<string, unknown> | MapLike<string, unknown>;
    constructor(options: Options);
    getValue<T>(...args: Parameters<KeyValueStore['getValue']>): Promise<T>;
    setValue<T>(...args: Parameters<KeyValueStore['setValue']>): Promise<void>;
    saveSnapshot(): Promise<void>;
    skipLinks(): void;
    enqueueRequest(requestOpts?: RequestOptions, options?: RequestQueueOperationOptions): ReturnType<RequestQueueV2['addRequest']>;
}
interface Context<Options extends ContextOptions = ContextOptions, ExtraFields extends ContextOptions['pageFunctionArguments'] = Options['pageFunctionArguments']> extends ExtraFields {
}
/**
 * Creates a Context by passing all arguments to its constructor
 * and returns it, along with a reference to its state object.
 */
export declare function createContext<Options extends ContextOptions = ContextOptions, ExtraFields extends ContextOptions['pageFunctionArguments'] = Options['pageFunctionArguments']>(contextOptions: Options): {
    context: Context<Options, ExtraFields>;
    state: InternalState;
};
export {};
//# sourceMappingURL=context.d.ts.map