import type { Request, Session } from '@crawlee/core';
import type { Cookie } from '@crawlee/types';
import { createRequestDebugInfo } from '@crawlee/utils';
import type { Dictionary } from '@crawlee/utils';
/**
 * Transforms a page function string into a Function object.
 * @param funcString
 */
export declare function evalFunctionOrThrow(funcString: string): (...args: unknown[]) => unknown;
/**
 * Transforms a pre/post navigation hooks string into array of Functions.
 * @param hooksString
 * @param paramName
 */
export declare function evalFunctionArrayOrThrow(hooksString: string, paramName: string): ((...args: unknown[]) => any)[];
/**
 * Validates the INPUT using the AJV library against the schema.
 */
export declare function checkInputOrThrow(input: unknown, schema: Dictionary): void;
export interface RequestMetadata {
    depth: number;
    parentRequestId: string | null;
}
/**
 * MODIFIES the provided Request by attaching necessary metadata.
 * Currently it only adds depth metadata, but it may be extended
 * as needed.
 */
export declare function ensureMetaData(request: Request): void;
/**
 * Merges the result of the page function, that may be a single object
 * or an array objects, with request metadata and a flag, whether
 * an error occured. This would typically be used after the page
 * had been retried and the failedRequestHandler was called.
 *
 * If an Object[] is returned from the page function, each of the objects
 * will have the metadata appended for consistency, since the dataset
 * will flatten the results.
 */
export declare function createDatasetPayload(request: Request, response: Parameters<typeof createRequestDebugInfo>[1], pageFunctionResult?: Dictionary | Dictionary[], isError?: boolean): {
    '#error': boolean;
    '#debug': Dictionary;
}[];
/**
 * Creates a 12 byte random hash encoded as base64
 * to be used as identifier.
 */
export declare function createRandomHash(): Promise<string>;
/**
 * Checks whether an item is a plain object,
 * i.e. not a function or array as _.isObject()
 * would check for.
 */
export declare function isPlainObject(item: unknown): item is Record<string, unknown>;
/**
 * Attempts to load Page Function from disk if it's not available
 * on INPUT.
 */
export declare function maybeLoadPageFunctionFromDisk(input: Dictionary, root: string): void;
export interface ErrorLike {
    message?: string;
    stack?: string;
}
/**
 * Creates an error constructed using props
 * from the provided object.
 */
export declare function createError(obj?: ErrorLike): Error;
export declare function logPerformance(request: Request, title: string, hrtime: [number, number]): void;
/**
 * Accepts an array of cookies in a { name, value }
 * format and finds if any of them are missing from
 * the session cookies for a given URL.
 */
export declare function getMissingCookiesFromSession(session: Session, cookies: Cookie[], url: string): Cookie[];
//# sourceMappingURL=tools.d.ts.map